# mypy-boto3-mediapackage-vod

[![PyPI - mypy-boto3-mediapackage-vod](https://img.shields.io/pypi/v/mypy-boto3-mediapackage-vod.svg?color=blue)](https://pypi.org/project/mypy-boto3-mediapackage-vod)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-mediapackage-vod.svg?color=blue)](https://pypi.org/project/mypy-boto3-mediapackage-vod)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-mediapackage-vod?color=blue)](https://pypistats.org/packages/mypy-boto3-mediapackage-vod)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.MediaPackageVod 1.17.64](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage-vod.html#MediaPackageVod)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.10.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-mediapackage-vod docs](https://github.com/vemel/mypy_boto3_builder/service_docs/mypy_boto3_mediapackage_vod/README.md)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-mediapackage-vod](#mypy-boto3-mediapackage-vod)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)

## How to install

Install `boto3-stubs` for `MediaPackageVod` service.

```bash
python -m pip install boto3-stubs[mediapackage-vod]
```

## Usage

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[mediapackage-vod]` in your environment:
  `python -m pip install 'boto3-stubs[mediapackage-vod]'`

Both type checking and auto-complete should work for `MediaPackageVod` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[mediapackage-vod]` in your environment:
  `python -m pip install 'boto3-stubs[mediapackage-vod]'`

Both type checking and auto-complete should work for `MediaPackageVod` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[mediapackage-vod]` in your environment:
  `python -m pip install 'boto3-stubs[mediapackage-vod]'`
- Run `mypy` as usual

Type checking should work for `MediaPackageVod` service. No explicit type
annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[mediapackage-vod]` in your environment:
  `python -m pip install 'boto3-stubs[mediapackage-vod]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `MediaPackageVod` service. No explicit type
annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`MediaPackageVodClient` provides annotations for
`boto3.client("mediapackage-vod")`.

```python
import boto3

from mypy_boto3_mediapackage_vod import MediaPackageVodClient

client: MediaPackageVodClient = boto3.client("mediapackage-vod")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: MediaPackageVodClient = session.client("mediapackage-vod")
```

### Paginators annotations

`mypy_boto3_mediapackage_vod.paginator` module contains type annotations for
all paginators.

```python
from mypy_boto3_mediapackage_vod import MediaPackageVodClient
from mypy_boto3_mediapackage_vod.paginator import (
    ListAssetsPaginator,
    ListPackagingConfigurationsPaginator,
    ListPackagingGroupsPaginator,
)

client: MediaPackageVodClient = boto3.client("mediapackage-vod")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_assets_paginator: ListAssetsPaginator = client.get_paginator("list_assets")
list_packaging_configurations_paginator: ListPackagingConfigurationsPaginator = client.get_paginator("list_packaging_configurations")
list_packaging_groups_paginator: ListPackagingGroupsPaginator = client.get_paginator("list_packaging_groups")
```

### Literals

`mypy_boto3_mediapackage_vod.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_mediapackage_vod.literals import (
    AdMarkers,
    EncryptionMethod,
    ListAssetsPaginatorName,
    ListPackagingConfigurationsPaginatorName,
    ListPackagingGroupsPaginatorName,
    ManifestLayout,
    Profile,
    SegmentTemplateFormat,
    StreamOrder,
    __PeriodTriggersElement,
)

def check_value(value: AdMarkers) -> bool:
    ...
```

### Typed dictionaries

`mypy_boto3_mediapackage_vod.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_mediapackage_vod.type_defs import (
    AssetShallowTypeDef,
    AuthorizationTypeDef,
    CmafEncryptionTypeDef,
    CmafPackageTypeDef,
    ConfigureLogsResponseTypeDef,
    CreateAssetResponseTypeDef,
    CreatePackagingConfigurationResponseTypeDef,
    CreatePackagingGroupResponseTypeDef,
    DashEncryptionTypeDef,
    DashManifestTypeDef,
    DashPackageTypeDef,
    DescribeAssetResponseTypeDef,
    DescribePackagingConfigurationResponseTypeDef,
    DescribePackagingGroupResponseTypeDef,
    EgressAccessLogsTypeDef,
    EgressEndpointTypeDef,
    HlsEncryptionTypeDef,
    HlsManifestTypeDef,
    HlsPackageTypeDef,
    ListAssetsResponseTypeDef,
    ListPackagingConfigurationsResponseTypeDef,
    ListPackagingGroupsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    MssEncryptionTypeDef,
    MssManifestTypeDef,
    MssPackageTypeDef,
    PackagingConfigurationTypeDef,
    PackagingGroupTypeDef,
    PaginatorConfigTypeDef,
    SpekeKeyProviderTypeDef,
    StreamSelectionTypeDef,
    UpdatePackagingGroupResponseTypeDef,
)

def get_structure() -> AssetShallowTypeDef:
    return {
      ...
    }
```
